# lstenv

Tool for generating, syncing, and auditing .env files by scanning code.

[![PyPI](https://img.shields.io/pypi/v/lstenv)](https://pypi.org/project/lstenv)
[![Downloads](https://pepy.tech/badge/lstenv)](https://pepy.tech/project/lstenv)
[![Documentation](https://img.shields.io/badge/docs-USAGE.md-blue)](https://github.com/aycsi/lstenv/blob/main/USAGE.md)


## Installation

```bash
pip install lstenv
```

## Documentation
- [![Documentation](https://img.shields.io/badge/docs-USAGE.md-blue)](https://github.com/aycsi/lstenv/blob/main/USAGE.md)

## License

MIT License

